usps-track
==========

.. include:: badges.rst

Quickly track via SMS several USPS (and some international) tracking numbers via the command line.

Commands
--------

.. click:: usps_track.main:main
  :prog: usps-track
  :nested: full

.. only:: html

   Library
   -------
   .. automodule:: usps_track.constants
      :members:

   .. automodule:: usps_track.lib
      :members:

   .. automodule:: usps_track.utils
      :members:

   .. toctree::
      :maxdepth: 2
      :caption: Contents:

   Indices and tables
   ==================
   * :ref:`genindex`
   * :ref:`modindex`
   * :ref:`search`
